@@ -1,4 +1,4 @@
-if [ ! -f /etc/xpdfrc ]
+if [ ! -e /etc/xpdfrc ]
 then
     /usr/bin/mkdir -p /etc
     /usr/bin/cp /etc/defaults/etc/xpdfrc /etc/xpdfrc
